/*
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */


#ifndef _PIN_MUX_H_
#define _PIN_MUX_H_

/***********************************************************************************************************************
 * Definitions
 **********************************************************************************************************************/

/*! @brief Direction type  */
typedef enum _pin_mux_direction
{
    kPIN_MUX_DirectionInput = 0U,        /* Input direction */
    kPIN_MUX_DirectionOutput = 1U,       /* Output direction */
    kPIN_MUX_DirectionInputOrOutput = 2U /* Input or output direction */
} pin_mux_direction_t;

/*!
 * @addtogroup pin_mux
 * @{
 */

/***********************************************************************************************************************
 * API
 **********************************************************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif


#define SOPT5_LPUART0RXSRC_LPUART_RX 0x00u /*!<@brief LPUART0 Receive Data Source Select: LPUART_RX pin */
#define SOPT5_LPUART0TXSRC_LPUART_TX 0x00u /*!<@brief LPUART0 Transmit Data Source Select: LPUART0_TX pin */

/*! @name PORTA1 (number 23), J1[2]/D0/UART0_RX
  @{ */
#define BOARD_DEBUG_UART0_RX_PERIPHERAL LPUART0        /*!<@brief Device name: LPUART0 */
#define BOARD_DEBUG_UART0_RX_SIGNAL RX                 /*!<@brief LPUART0 signal: RX */
#define BOARD_DEBUG_UART0_RX_PORT PORTA                /*!<@brief PORT device name: PORTA */
#define BOARD_DEBUG_UART0_RX_PIN 1U                    /*!<@brief PORTA pin index: 1 */
#define BOARD_DEBUG_UART0_RX_PIN_NAME LPUART0_RX       /*!<@brief Pin name */
#define BOARD_DEBUG_UART0_RX_LABEL "J1[2]/D0/UART0_RX" /*!<@brief Label */
#define BOARD_DEBUG_UART0_RX_NAME "DEBUG_UART0_RX"     /*!<@brief Identifier name */
                                                       /* @} */

/*! @name PORTA2 (number 24), J1[4]/D1/UART0_TX
  @{ */
#define BOARD_DEBUG_UART0_TX_PERIPHERAL LPUART0        /*!<@brief Device name: LPUART0 */
#define BOARD_DEBUG_UART0_TX_SIGNAL TX                 /*!<@brief LPUART0 signal: TX */
#define BOARD_DEBUG_UART0_TX_PORT PORTA                /*!<@brief PORT device name: PORTA */
#define BOARD_DEBUG_UART0_TX_PIN 2U                    /*!<@brief PORTA pin index: 2 */
#define BOARD_DEBUG_UART0_TX_PIN_NAME LPUART0_TX       /*!<@brief Pin name */
#define BOARD_DEBUG_UART0_TX_LABEL "J1[4]/D1/UART0_TX" /*!<@brief Label */
#define BOARD_DEBUG_UART0_TX_NAME "DEBUG_UART0_TX"     /*!<@brief Identifier name */
                                                       /* @} */

/*! @name PORTE31 (number 19), LED2
  @{ */
#define BOARD_LED2_PERIPHERAL TPM0   /*!<@brief Device name: TPM0 */
#define BOARD_LED2_SIGNAL CH         /*!<@brief TPM0 signal: CH */
#define BOARD_LED2_PORT PORTE        /*!<@brief PORT device name: PORTE */
#define BOARD_LED2_PIN 31U           /*!<@brief PORTE pin index: 31 */
#define BOARD_LED2_CHANNEL 4         /*!<@brief TPM0 channel: 4 */
#define BOARD_LED2_PIN_NAME TPM0_CH4 /*!<@brief Pin name */
#define BOARD_LED2_LABEL "LED2"      /*!<@brief Label */
#define BOARD_LED2_NAME "LED2"       /*!<@brief Identifier name */
                                     /* @} */

/*! @name PORTD5 (number 62), J2[12]/D13/SPI1_SCK/LED1/LCD_P45
  @{ */
#define BOARD_LED1_PERIPHERAL TPM0                          /*!<@brief Device name: TPM0 */
#define BOARD_LED1_SIGNAL CH                                /*!<@brief TPM0 signal: CH */
#define BOARD_LED1_PORT PORTD                               /*!<@brief PORT device name: PORTD */
#define BOARD_LED1_PIN 5U                                   /*!<@brief PORTD pin index: 5 */
#define BOARD_LED1_CHANNEL 5                                /*!<@brief TPM0 channel: 5 */
#define BOARD_LED1_PIN_NAME TPM0_CH5                        /*!<@brief Pin name */
#define BOARD_LED1_LABEL "J2[12]/D13/SPI1_SCK/LED1/LCD_P45" /*!<@brief Label */
#define BOARD_LED1_NAME "LED1"                              /*!<@brief Identifier name */
                                                            /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPins(void);

/*! @name PORTE24 (number 20), U2[7]/U10[4]/I2C0_SCL
  @{ */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PERIPHERAL I2C0               /*!<@brief Device name: I2C0 */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_SIGNAL SCL                    /*!<@brief I2C0 signal: SCL */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PORT PORTE                    /*!<@brief PORT device name: PORTE */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PIN 24U                       /*!<@brief PORTE pin index: 24 */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PIN_NAME I2C0_SCL             /*!<@brief Pin name */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_LABEL "U2[7]/U10[4]/I2C0_SCL" /*!<@brief Label */
#define BOARD_I2C_CONFIGUREPINS_I2C0_SCL_NAME "I2C0_SCL"               /*!<@brief Identifier name */
                                                                       /* @} */

/*! @name PORTE25 (number 21), U2[6]/U10[6]/I2C0_SDA
  @{ */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PERIPHERAL I2C0               /*!<@brief Device name: I2C0 */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_SIGNAL SDA                    /*!<@brief I2C0 signal: SDA */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PORT PORTE                    /*!<@brief PORT device name: PORTE */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PIN 25U                       /*!<@brief PORTE pin index: 25 */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PIN_NAME I2C0_SDA             /*!<@brief Pin name */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_LABEL "U2[6]/U10[6]/I2C0_SDA" /*!<@brief Label */
#define BOARD_I2C_CONFIGUREPINS_I2C1_SDA_NAME "I2C1_SDA"               /*!<@brief Identifier name */
                                                                       /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_I2C_ConfigurePins(void);

#if defined(__cplusplus)
}
#endif

/*!
 * @}
 */
#endif /* _PIN_MUX_H_ */

/***********************************************************************************************************************
 * EOF
 **********************************************************************************************************************/
