/*
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */


/* clang-format off */
/*
 * TEXT BELOW IS USED AS SETTING FOR TOOLS *************************************

!!GlobalInfo

product: Pins v3.0

processor: MKL43Z256xxx4

package_id: MKL43Z256VLH4

mcu_data: ksdk2_0

processor_version: 0.0.8

board: FRDM-KL43Z

 * BE CAREFUL MODIFYING THIS COMMENT - IT IS YAML SETTINGS FOR TOOLS ***********
 */
/* clang-format on */

#include "fsl_common.h"
#include "fsl_port.h"
#include "pin_mux.h"



/* clang-format off */
/*
 * TEXT BELOW IS USED AS SETTING FOR TOOLS *************************************

BOARD_InitPins:

- options: {callFromInitBoot: 'true', prefix: BOARD_, coreID: core0, enableClock: 'true'}

- pin_list:

  - {pin_num: '23', peripheral: LPUART0, signal: RX, pin_signal: PTA1/LPUART0_RX/TPM2_CH0}

  - {pin_num: '24', peripheral: LPUART0, signal: TX, pin_signal: PTA2/LPUART0_TX/TPM2_CH1}

  - {pin_num: '19', peripheral: TPM0, signal: 'CH, 4', pin_signal: PTE31/TPM0_CH4, slew_rate: fast, pull_select: up, pull_enable: enable}

  - {pin_num: '62', peripheral: TPM0, signal: 'CH, 5', pin_signal: LCD_P45/ADC0_SE6b/PTD5/SPI1_SCK/UART2_TX/TPM0_CH5/FXIO0_D5, slew_rate: fast, pull_select: up, pull_enable: enable}

 * BE CAREFUL MODIFYING THIS COMMENT - IT IS YAML SETTINGS FOR TOOLS ***********
 */
/* clang-format on */

/* FUNCTION ************************************************************************************************************
 *
 * Function Name : BOARD_InitPins
 * Description   : Configures pin routing and optionally pin electrical features.
 *
 * END ****************************************************************************************************************/
void BOARD_InitPins(void)
{
    /* Port A Clock Gate Control: Clock enabled */
    CLOCK_EnableClock(kCLOCK_PortA);
    /* Port D Clock Gate Control: Clock enabled */
    CLOCK_EnableClock(kCLOCK_PortD);
    /* Port E Clock Gate Control: Clock enabled */
    CLOCK_EnableClock(kCLOCK_PortE);

    /* PORTA1 (pin 23) is configured as LPUART0_RX */
    PORT_SetPinMux(BOARD_DEBUG_UART0_RX_PORT, BOARD_DEBUG_UART0_RX_PIN, kPORT_MuxAlt2);

    /* PORTA2 (pin 24) is configured as LPUART0_TX */
    PORT_SetPinMux(BOARD_DEBUG_UART0_TX_PORT, BOARD_DEBUG_UART0_TX_PIN, kPORT_MuxAlt2);

    const port_pin_config_t LED1 = {/* Internal pull-up resistor is enabled */
                                    kPORT_PullUp,
                                    /* Fast slew rate is configured */
                                    kPORT_FastSlewRate,
                                    /* Passive filter is disabled */
                                    kPORT_PassiveFilterDisable,
                                    /* Low drive strength is configured */
                                    kPORT_LowDriveStrength,
                                    /* Pin is configured as TPM0_CH5 */
                                    kPORT_MuxAlt4};
    /* PORTD5 (pin 62) is configured as TPM0_CH5 */
    PORT_SetPinConfig(BOARD_LED1_PORT, BOARD_LED1_PIN, &LED1);

    const port_pin_config_t LED2 = {/* Internal pull-up resistor is enabled */
                                    kPORT_PullUp,
                                    /* Fast slew rate is configured */
                                    kPORT_FastSlewRate,
                                    /* Passive filter is disabled */
                                    kPORT_PassiveFilterDisable,
                                    /* Low drive strength is configured */
                                    kPORT_LowDriveStrength,
                                    /* Pin is configured as TPM0_CH4 */
                                    kPORT_MuxAlt3};
    /* PORTE31 (pin 19) is configured as TPM0_CH4 */
    PORT_SetPinConfig(BOARD_LED2_PORT, BOARD_LED2_PIN, &LED2);

    SIM->SOPT5 = ((SIM->SOPT5 &
                   /* Mask bits to zero which are setting */
                   (~(SIM_SOPT5_LPUART0TXSRC_MASK | SIM_SOPT5_LPUART0RXSRC_MASK)))

                  /* LPUART0 Transmit Data Source Select: LPUART0_TX pin. */
                  | SIM_SOPT5_LPUART0TXSRC(SOPT5_LPUART0TXSRC_LPUART_TX)

                  /* LPUART0 Receive Data Source Select: LPUART_RX pin. */
                  | SIM_SOPT5_LPUART0RXSRC(SOPT5_LPUART0RXSRC_LPUART_RX));
}

/* clang-format off */
/*
 * TEXT BELOW IS USED AS SETTING FOR TOOLS *************************************

BOARD_I2C_ConfigurePins:

- options: {coreID: core0, enableClock: 'true'}

- pin_list:

  - {pin_num: '20', peripheral: I2C0, signal: SCL, pin_signal: PTE24/TPM0_CH0/I2C0_SCL, slew_rate: fast, pull_select: up, pull_enable: enable}

  - {pin_num: '21', peripheral: I2C0, signal: SDA, pin_signal: PTE25/TPM0_CH1/I2C0_SDA, slew_rate: fast, pull_select: up, pull_enable: enable}

 * BE CAREFUL MODIFYING THIS COMMENT - IT IS YAML SETTINGS FOR TOOLS ***********
 */
/* clang-format on */

/* FUNCTION ************************************************************************************************************
 *
 * Function Name : BOARD_I2C_ConfigurePins
 * Description   : Configures pin routing and optionally pin electrical features.
 *
 * END ****************************************************************************************************************/
void BOARD_I2C_ConfigurePins(void)
{
    /* Port E Clock Gate Control: Clock enabled */
    CLOCK_EnableClock(kCLOCK_PortE);

    const port_pin_config_t I2C0_SCL = {/* Internal pull-up resistor is enabled */
                                        kPORT_PullUp,
                                        /* Fast slew rate is configured */
                                        kPORT_FastSlewRate,
                                        /* Passive filter is disabled */
                                        kPORT_PassiveFilterDisable,
                                        /* Low drive strength is configured */
                                        kPORT_LowDriveStrength,
                                        /* Pin is configured as I2C0_SCL */
                                        kPORT_MuxAlt5};
    /* PORTE24 (pin 20) is configured as I2C0_SCL */
    PORT_SetPinConfig(BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PORT, BOARD_I2C_CONFIGUREPINS_I2C0_SCL_PIN, &I2C0_SCL);

    const port_pin_config_t I2C1_SDA = {/* Internal pull-up resistor is enabled */
                                        kPORT_PullUp,
                                        /* Fast slew rate is configured */
                                        kPORT_FastSlewRate,
                                        /* Passive filter is disabled */
                                        kPORT_PassiveFilterDisable,
                                        /* Low drive strength is configured */
                                        kPORT_LowDriveStrength,
                                        /* Pin is configured as I2C0_SDA */
                                        kPORT_MuxAlt5};
    /* PORTE25 (pin 21) is configured as I2C0_SDA */
    PORT_SetPinConfig(BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PORT, BOARD_I2C_CONFIGUREPINS_I2C1_SDA_PIN, &I2C1_SDA);
}
/***********************************************************************************************************************
 * EOF
 **********************************************************************************************************************/
